# TMart

Home page: [https://github.com/yulunwu8/tmart](https://github.com/yulunwu8/tmart)

User instruction: [https://tmart-rtm.github.io](https://tmart-rtm.github.io) 

## Installation 

1 - Create a conda environment and activate it: 

```
conda create --name tmart
conda activate tmart
```

2 - Install dependencies: 

```
conda install -c conda-forge Py6S numpy pandas scipy pathos matplotlib
```

3 - Install tmart: 

```
pip3 install tmart
```



## Other


For questions and suggestions (which I'm always open to!), please email [ywu146@uottawa.ca](ywu146@uottawa.ca)